summaryrefslogtreecommitdiffhomepage
path: root/Kernel/KernelKit/DeviceManager.hpp
diff options
context:
space:
mode:
authorAmlal EL Mahrouss <amlalelmahrouss@icloud.com>2024-07-02 22:00:35 +0200
committerAmlal EL Mahrouss <amlalelmahrouss@icloud.com>2024-07-02 22:00:49 +0200
commit375d0210dcb2070a12d916523f4a1dafff28360c (patch)
treed0c217f529b8069ea659778c2ee9ca20aeba33a4 /Kernel/KernelKit/DeviceManager.hpp
parentf1d3744829a661d1600c2f3bbdbdf679ee0bd0e1 (diff)
MHR-36: Change namespace name, got out of the codename stage.
Signed-off-by: Amlal EL Mahrouss <amlalelmahrouss@icloud.com>
Diffstat (limited to 'Kernel/KernelKit/DeviceManager.hpp')
-rw-r--r--Kernel/KernelKit/DeviceManager.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/Kernel/KernelKit/DeviceManager.hpp b/Kernel/KernelKit/DeviceManager.hpp
index 11217fc6..219977f4 100644
--- a/Kernel/KernelKit/DeviceManager.hpp
+++ b/Kernel/KernelKit/DeviceManager.hpp
@@ -14,7 +14,7 @@
#pragma once
/* NewOS device interface manager. */
/* @file KernelKit/DeviceManager.hpp */
/* @brief Device abstraction and I/O buffer. */
@@ -24,7 +24,7 @@
// Last Rev
// Wed, Apr 3, 2024 9:09:41 AM
-namespace NewOS
+namespace Kernel
{
template <typename T>
class DeviceInterface;
@@ -126,4 +126,4 @@ namespace NewOS
kDeviceTypeMedia,
kDeviceTypeCount,
};
-} // namespace NewOS
+} // namespace Kernel
@@ -14,7 +14,7 @@
#pragma once
-/* NewOS device interface manager. */
+/* Kernel device interface manager. */
/* @file KernelKit/DeviceManager.hpp */
/* @brief Device abstraction and I/O buffer. */